<?php

if ( ! function_exists( 'chalet_set_404_page_inner_classes' ) ) {
	/**
	 * Function that return classes for the page inner div from header.php
	 *
	 * @param string $classes
	 *
	 * @return string
	 */
	function chalet_set_404_page_inner_classes( $classes ) {

		if ( is_404() ) {
			$classes = 'qodef-content-full-width';
		}

		return $classes;
	}

	add_filter( 'chalet_filter_page_inner_classes', 'chalet_set_404_page_inner_classes' );
}

if ( ! function_exists( 'chalet_get_404_page_parameters' ) ) {
	/**
	 * Function that set 404 page area content parameters
	 */
	function chalet_get_404_page_parameters() {

		$params = array(
			'title'       => esc_html__( '404', 'chalet' ),
			'text'        => esc_html__( 'The page you are looking for is missing or have been moved or deleted', 'chalet' ),
			'button_text' => esc_html__( 'Return to home', 'chalet' ),
		);

		return apply_filters( 'chalet_filter_404_page_template_params', $params );
	}
}

if ( ! function_exists( 'chalet_core_get_page_404_text' ) ) {
	/**
	 * Function that returns modified page 404 text
	 */
	function chalet_core_get_page_404_text() {
		$page_404_params          = chalet_get_404_page_parameters();
		$page_404_text            = $page_404_params['text'];
		$text_highlight_positions = chalet_is_installed( 'core' ) ? chalet_core_get_post_value_through_levels( 'qodef_404_page_text_highlight_positions' ) : '';
		$text                     = $page_404_text;

		if ( ! empty( $page_404_text ) && ! empty( $text_highlight_positions ) ) {
			$split_text          = explode( ' ', $page_404_text );
			$highlight_positions = explode( ',', str_replace( ' ', '', $text_highlight_positions ) );

			foreach ( $highlight_positions as $position ) {
				$position = intval( $position );
				if ( isset( $split_text[$position - 1] ) && ! empty( $split_text[$position - 1] ) ) {
					$split_text[$position - 1] = '<span class="qodef-404-text--italic">' . $split_text[$position - 1] . '</span>';
				}
			}

			$text = implode( ' ', $split_text );
		}

		return $text;
	}
}
